pub enum TimeLeft {
Remaining(u64),
Overdue(u64),
Completed,
NoDue,
}Expand description
Describes how much time is left to complete this task, or perhaps that it is overdue or has been deleted.
Variants
Remaining(u64)
The length of time in seconds until this item is due (in the future)
Overdue(u64)
The task is overdue by this count of seconds
Completed
Already completed
NoDue
No due date